Author: stefan2
Date: Thu May 2 20:03:57 2013
New Revision: 1478509
URL: http://svn.apache.org/r1478509
Log:
On the fsfs-format7 branch: say "changed paths list" instead "changes
list" to avoid confusion with the client-side "changelist" feature.
* subversion/libsvn_fs_fs/changes.c
(): update file comment
* subversion/libsvn_fs_fs/changes.h
(): ditto
* subversion/libsvn_fs_fs/low_level.h
(svn_fs_fs__parse_revision_trailer,
svn_fs_fs__unparse_revision_trailer,
svn_fs_fs__write_changes): update docstring
* subversion/libsvn_fs_fs/pack.c
(copy_item_to_temp): ditto
* subversion/tests/libsvn_fs_base/changes-test.c
(changes_fetch_raw): ditto
* tools/dev/fsfs-reorg.c
(revision_location_t,
add_revisions_pack_heads,
get_fragment_content): ditto
* tools/server-side/fsfs-stats.c
(revision_info_t,
get_change_count): ditto
Suggested by: danielsh
Modified:
subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.c
subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.h
subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/low_level.h
subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/pack.c
subversion/branches/fsfs-format7/subversion/tests/libsvn_fs_base/changes-test.c
subversion/branches/fsfs-format7/tools/dev/fsfs-reorg.c
subversion/branches/fsfs-format7/tools/server-side/fsfs-stats.c
Modified: subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.c
URL:
http://svn.apache.org/viewvc/subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.c?rev=1478509&r1=1478508&r2=1478509&view=diff
==============================================================================
--- subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.c
(original)
+++ subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.c Thu May
2 20:03:57 2013
@@ -1,4 +1,4 @@
-/* changes.h --- FSFS changes lists container
+/* changes.h --- FSFS changed paths lists container
*
* ====================================================================
* Licensed to the Apache Software Foundation (ASF) under one
Modified: subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.h
URL:
http://svn.apache.org/viewvc/subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.h?rev=1478509&r1=1478508&r2=1478509&view=diff
==============================================================================
--- subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.h
(original)
+++ subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/changes.h Thu May
2 20:03:57 2013
@@ -1,4 +1,4 @@
-/* changes.h --- FSFS changes lists container
+/* changes.h --- FSFS changed paths lists container
*
* ====================================================================
* Licensed to the Apache Software Foundation (ASF) under one
Modified: subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/low_level.h
URL:
http://svn.apache.org/viewvc/subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/low_level.h?rev=1478509&r1=1478508&r2=1478509&view=diff
==============================================================================
--- subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/low_level.h
(original)
+++ subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/low_level.h Thu
May 2 20:03:57 2013
@@ -31,9 +31,9 @@
/* Given the last "few" bytes (should be at least 40) of revision REV in
* TRAILER, parse the last line and return the offset of the root noderev
- * in *ROOT_OFFSET and the offset of the changes list in *CHANGES_OFFSET.
- * All offsets are relative to the revision's start offset. ROOT_OFFSET
- * and / or CHANGES_OFFSET may be NULL.
+ * in *ROOT_OFFSET and the offset of the changed paths list in
+ * *CHANGES_OFFSET. Offsets are relative to the revision's start offset.
+ * ROOT_OFFSET and / or CHANGES_OFFSET may be NULL.
*
* Note that REV is only used to construct nicer error objects.
*/
@@ -44,8 +44,8 @@ svn_fs_fs__parse_revision_trailer(apr_of
svn_revnum_t rev);
/* Given the offset of the root noderev in ROOT_OFFSET and the offset of
- * the changes list in CHANGES_OFFSET, return the corresponding revision's
- * trailer. Allocate it in POOL.
+ * the changed paths list in CHANGES_OFFSET, return the corresponding
+ * revision's trailer. Allocate it in POOL.
*/
svn_stringbuf_t *
svn_fs_fs__unparse_revision_trailer(apr_off_t root_offset,
@@ -143,7 +143,7 @@ svn_fs_fs__read_changes(apr_array_header
/* Write the changed path info from CHANGES in filesystem FS to the
output stream STREAM. You may call this function multiple time on
the same stream but the last call should set TERMINATE_LIST to write
- an extra empty line that marks the end of the changes list.
+ an extra empty line that marks the end of the changed paths list.
Perform temporary allocations in POOL.
*/
svn_error_t *
Modified: subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/pack.c
URL:
http://svn.apache.org/viewvc/subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/pack.c?rev=1478509&r1=1478508&r2=1478509&view=diff
==============================================================================
--- subversion/branches/fsfs-format7/tools/dev/fsfs-reorg.c (original)
+++ subversion/branches/fsfs-format7/tools/dev/fsfs-reorg.c Thu May 2 20:03:57
2013
@@ -106,10 +106,10 @@ typedef struct revision_location_t
/* pack file offset (manifest value), 0 for non-packed files */
apr_size_t offset;
- /* offset of the changes list relative to OFFSET */
+ /* offset of the changed paths list relative to OFFSET */
apr_size_t changes;
- /* length of the changes list on bytes */
+ /* length of the changed paths list on bytes */
apr_size_t changes_len;
/* first offset behind the revision data in the pack file (file length
@@ -2003,7 +2003,7 @@ add_revisions_pack_heads(revision_pack_t
info = APR_ARRAY_IDX(pack->info, pack->info->nelts - 1, revision_info_t*);
info->target.offset = pack->target_offset;
- /* followed by the changes list */
+ /* followed by the changed paths list */
for (i = 0; i < pack->info->nelts; ++i)
{
@@ -2838,7 +2838,7 @@ get_fragment_content(svn_string_t **cont
info->target.changes);
return SVN_NO_ERROR;
- /* The changes list remains untouched */
+ /* The changed paths list remains untouched */
case changes_fragment:
info = fragment->data;
SVN_ERR(get_content(&revision_content, fs, info->revision, pool));
Modified: subversion/branches/fsfs-format7/tools/server-side/fsfs-stats.c
URL:
http://svn.apache.org/viewvc/subversion/branches/fsfs-format7/tools/server-side/fsfs-stats.c?rev=1478509&r1=1478508&r2=1478509&view=diff
==============================================================================
--- subversion/branches/fsfs-format7/tools/server-side/fsfs-stats.c (original)
+++ subversion/branches/fsfs-format7/tools/server-side/fsfs-stats.c Thu May 2
20:03:57 2013
@@ -118,13 +118,13 @@ typedef struct revision_info_t
/* pack file offset (manifest value), 0 for non-packed files */
apr_size_t offset;
- /* offset of the changes list relative to OFFSET */
+ /* offset of the changed paths list relative to OFFSET */
apr_size_t changes;
- /* length of the changes list on bytes */
+ /* length of the changed paths list on bytes */
apr_size_t changes_len;
- /* offset of the changes list relative to OFFSET */
+ /* offset of the changed paths list relative to OFFSET */
apr_size_t change_count;
/* first offset behind the revision data in the pack file (file length
@@ -1380,8 +1380,8 @@ read_noderev(fs_fs_t *fs,
return SVN_NO_ERROR;
}
-/* Given the unparsed changes list in CHANGES with LEN chars, return the
- * number of changed paths encoded in it.
+/* Given the unparsed changed paths list in CHANGES with LEN chars, return
+ * the number of changed paths encoded in it.
*/
static apr_size_t
get_change_count(const char *changes,
--- subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/pack.c (original)
+++ subversion/branches/fsfs-format7/subversion/libsvn_fs_fs/pack.c Thu May 2
20:03:57 2013
@@ -422,9 +422,9 @@ write_null_bytes(apr_file_t *dest,
return SVN_NO_ERROR;
}
/* Copy the "simple" item (changes list or property representation) from
* the current position in REV_FILE to TEMP_FILE using CONTEXT. Add a
* copy of ENTRY to ENTRIES but with an updated offset value that points
* to the copy destination in TEMP_FILE. Use POOL for allocations.
*/
static svn_error_t *
Modified:
subversion/branches/fsfs-format7/subversion/tests/libsvn_fs_base/changes-test.c
URL:
http://svn.apache.org/viewvc/subversion/branches/fsfs-format7/subversion/tests/libsvn_fs_base/changes-test.c?rev=1478509&r1=1478508&r2=1478509&view=diff
==============================================================================
---
subversion/branches/fsfs-format7/subversion/tests/libsvn_fs_base/changes-test.c
(original)
+++
subversion/branches/fsfs-format7/subversion/tests/libsvn_fs_base/changes-test.c
Thu May 2 20:03:57 2013
@@ -210,7 +210,7 @@ changes_fetch_raw(const svn_test_opts_t
SVN_ERR(add_standard_changes(fs, pool));
/* For each transaction, fetch that transaction's changes, and
- compare those changes against the standard changes list. Order
+ compare those changes against the standard changed paths list. Order
matters throughout all the changes code, so we shouldn't have to
worry about ordering of the arrays. */
for (i = 0; i < num_txns; i++)
@@ -422,9 +422,9 @@ write_null_bytes(apr_file_t *dest,
return SVN_NO_ERROR;
}
-/* Copy the "simple" item (changes list or property representation) from
- * the current position in REV_FILE to TEMP_FILE using CONTEXT. Add a
- * copy of ENTRY to ENTRIES but with an updated offset value that points
+/* Copy the "simple" item (changed paths list or property representation)
+ * from the current position in REV_FILE to TEMP_FILE using CONTEXT. Add
+ * a copy of ENTRY to ENTRIES but with an updated offset value that points
* to the copy destination in TEMP_FILE. Use POOL for allocations.
*/
Modified: subversion/branches/fsfs-format7/tools/dev/fsfs-reorg.c
URL:
http://svn.apache.org/viewvc/subversion/branches/fsfs-format7/tools/dev/fsfs-reorg.c?rev=1478509&r1=1478508&r2=1478509&view=diff
==============================================================================